# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/repository.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/repository/v1/repository.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x89\x01\n\x17\x43reateRepositoryRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0frepository_type\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x11\n\tsecret_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"Q\n\x17UpdateRepositoryRequest\x12\x15\n\rrepository_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"=\n\x11RepositoryRequest\x12\x15\n\rrepository_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"N\n\x14GetRepositoryRequest\x12\x15\n\rrepository_id\x18\x01 \x01(\t\x12\x0c\n\x04only\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\x8e\x01\n\x0fRepositoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0frepository_type\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x98\x01\n\x0eRepositoryInfo\x12\x15\n\rrepository_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0frepository_type\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x11\n\tsecret_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x14 \x01(\t\"d\n\x10RepositoriesInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13RepositoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x8d\x07\n\nRepository\x12\x90\x01\n\x08register\x12\x33.spaceone.api.repository.v1.CreateRepositoryRequest\x1a*.spaceone.api.repository.v1.RepositoryInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/repository/v1/repositories\x12\x9c\x01\n\x06update\x12\x33.spaceone.api.repository.v1.UpdateRepositoryRequest\x1a*.spaceone.api.repository.v1.RepositoryInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/repository/v1/repository/{repository_id}\x12\x86\x01\n\nderegister\x12-.spaceone.api.repository.v1.RepositoryRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+*)/repository/v1/repository/{repository_id}\x12\x98\x01\n\x03get\x12\x30.spaceone.api.repository.v1.GetRepositoryRequest\x1a*.spaceone.api.repository.v1.RepositoryInfo\"3\x82\xd3\xe4\x93\x02-\x12+/repository/v1/repositories/{repository_id}\x12\xac\x01\n\x04list\x12+.spaceone.api.repository.v1.RepositoryQuery\x1a,.spaceone.api.repository.v1.RepositoriesInfo\"I\x82\xd3\xe4\x93\x02\x43\x12\x1b/repository/v1/repositoriesZ$\"\"/repository/v1/repositories/search\x12z\n\x04stat\x12/.spaceone.api.repository.v1.RepositoryStatQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /repository/v1/repositories/statb\x06proto3')



_CREATEREPOSITORYREQUEST = DESCRIPTOR.message_types_by_name['CreateRepositoryRequest']
_UPDATEREPOSITORYREQUEST = DESCRIPTOR.message_types_by_name['UpdateRepositoryRequest']
_REPOSITORYREQUEST = DESCRIPTOR.message_types_by_name['RepositoryRequest']
_GETREPOSITORYREQUEST = DESCRIPTOR.message_types_by_name['GetRepositoryRequest']
_REPOSITORYQUERY = DESCRIPTOR.message_types_by_name['RepositoryQuery']
_REPOSITORYINFO = DESCRIPTOR.message_types_by_name['RepositoryInfo']
_REPOSITORIESINFO = DESCRIPTOR.message_types_by_name['RepositoriesInfo']
_REPOSITORYSTATQUERY = DESCRIPTOR.message_types_by_name['RepositoryStatQuery']
CreateRepositoryRequest = _reflection.GeneratedProtocolMessageType('CreateRepositoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPOSITORYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreateRepositoryRequest)
  })
_sym_db.RegisterMessage(CreateRepositoryRequest)

UpdateRepositoryRequest = _reflection.GeneratedProtocolMessageType('UpdateRepositoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPOSITORYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdateRepositoryRequest)
  })
_sym_db.RegisterMessage(UpdateRepositoryRequest)

RepositoryRequest = _reflection.GeneratedProtocolMessageType('RepositoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoryRequest)
  })
_sym_db.RegisterMessage(RepositoryRequest)

GetRepositoryRequest = _reflection.GeneratedProtocolMessageType('GetRepositoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositoryRequest)
  })
_sym_db.RegisterMessage(GetRepositoryRequest)

RepositoryQuery = _reflection.GeneratedProtocolMessageType('RepositoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYQUERY,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoryQuery)
  })
_sym_db.RegisterMessage(RepositoryQuery)

RepositoryInfo = _reflection.GeneratedProtocolMessageType('RepositoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYINFO,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoryInfo)
  })
_sym_db.RegisterMessage(RepositoryInfo)

RepositoriesInfo = _reflection.GeneratedProtocolMessageType('RepositoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORIESINFO,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoriesInfo)
  })
_sym_db.RegisterMessage(RepositoriesInfo)

RepositoryStatQuery = _reflection.GeneratedProtocolMessageType('RepositoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYSTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.repository_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoryStatQuery)
  })
_sym_db.RegisterMessage(RepositoryStatQuery)

_REPOSITORY = DESCRIPTOR.services_by_name['Repository']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORY.methods_by_name['register']._options = None
  _REPOSITORY.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\035\"\033/repository/v1/repositories'
  _REPOSITORY.methods_by_name['update']._options = None
  _REPOSITORY.methods_by_name['update']._serialized_options = b'\202\323\344\223\002+\032)/repository/v1/repository/{repository_id}'
  _REPOSITORY.methods_by_name['deregister']._options = None
  _REPOSITORY.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002+*)/repository/v1/repository/{repository_id}'
  _REPOSITORY.methods_by_name['get']._options = None
  _REPOSITORY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002-\022+/repository/v1/repositories/{repository_id}'
  _REPOSITORY.methods_by_name['list']._options = None
  _REPOSITORY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002C\022\033/repository/v1/repositoriesZ$\"\"/repository/v1/repositories/search'
  _REPOSITORY.methods_by_name['stat']._options = None
  _REPOSITORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\"\" /repository/v1/repositories/stat'
  _CREATEREPOSITORYREQUEST._serialized_start=199
  _CREATEREPOSITORYREQUEST._serialized_end=336
  _UPDATEREPOSITORYREQUEST._serialized_start=338
  _UPDATEREPOSITORYREQUEST._serialized_end=419
  _REPOSITORYREQUEST._serialized_start=421
  _REPOSITORYREQUEST._serialized_end=482
  _GETREPOSITORYREQUEST._serialized_start=484
  _GETREPOSITORYREQUEST._serialized_end=562
  _REPOSITORYQUERY._serialized_start=565
  _REPOSITORYQUERY._serialized_end=707
  _REPOSITORYINFO._serialized_start=710
  _REPOSITORYINFO._serialized_end=862
  _REPOSITORIESINFO._serialized_start=864
  _REPOSITORIESINFO._serialized_end=964
  _REPOSITORYSTATQUERY._serialized_start=966
  _REPOSITORYSTATQUERY._serialized_end=1060
  _REPOSITORY._serialized_start=1063
  _REPOSITORY._serialized_end=1972
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/repository/v1/schema.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a+spaceone/api/repository/v1/repository.proto\"\xef\x01\n\x13\x43reateSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cservice_type\x18\x02 \x01(\t\x12\x11\n\tschema_id\x18\x03 \x01(\t\x12\'\n\x06schema\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xb2\x01\n\x13UpdateSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x06schema\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"C\n\rSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x11\n\tschema_id\x18\x03 \x01(\t\"u\n\x1aGetRepositorySchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x0c\n\x04only\x18\x04 \x03(\t\x12\x11\n\tschema_id\x18\x05 \x01(\t\"\x9a\x02\n\x0bSchemaQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cservice_type\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x15\n\rrepository_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x11\n\tschema_id\x18\x07 \x01(\t\x12<\n\x05state\x18\x08 \x01(\x0e\x32-.spaceone.api.repository.v1.SchemaQuery.State\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xd3\x02\n\nSchemaInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cservice_type\x18\x02 \x01(\t\x12\x11\n\tschema_id\x18\x03 \x01(\t\x12\'\n\x06schema\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x0frepository_info\x18\x15 \x01(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\"[\n\x0bSchemasInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.repository.v1.SchemaInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"q\n\x0fSchemaStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\xad\x06\n\x06Schema\x12\x81\x01\n\x06\x63reate\x12/.spaceone.api.repository.v1.CreateSchemaRequest\x1a&.spaceone.api.repository.v1.SchemaInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/repository/v1/schemas\x12\x89\x01\n\x06update\x12/.spaceone.api.repository.v1.UpdateSchemaRequest\x1a&.spaceone.api.repository.v1.SchemaInfo\"&\x82\xd3\xe4\x93\x02 \x1a\x1e/repository/v1/schema/{schema}\x12s\n\x06\x64\x65lete\x12).spaceone.api.repository.v1.SchemaRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 *\x1e/repository/v1/schema/{schema}\x12\x8e\x01\n\x03get\x12\x36.spaceone.api.repository.v1.GetRepositorySchemaRequest\x1a&.spaceone.api.repository.v1.SchemaInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/repository/v1/schemas/{schema}\x12\x99\x01\n\x04list\x12\'.spaceone.api.repository.v1.SchemaQuery\x1a\'.spaceone.api.repository.v1.SchemasInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/repository/v1/schemasZ\x1f\"\x1d/repository/v1/schemas/search\x12q\n\x04stat\x12+.spaceone.api.repository.v1.SchemaStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/repository/v1/schemas/statb\x06proto3')



_CREATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['CreateSchemaRequest']
_UPDATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['UpdateSchemaRequest']
_SCHEMAREQUEST = DESCRIPTOR.message_types_by_name['SchemaRequest']
_GETREPOSITORYSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['GetRepositorySchemaRequest']
_SCHEMAQUERY = DESCRIPTOR.message_types_by_name['SchemaQuery']
_SCHEMAINFO = DESCRIPTOR.message_types_by_name['SchemaInfo']
_SCHEMASINFO = DESCRIPTOR.message_types_by_name['SchemasInfo']
_SCHEMASTATQUERY = DESCRIPTOR.message_types_by_name['SchemaStatQuery']
_SCHEMAQUERY_STATE = _SCHEMAQUERY.enum_types_by_name['State']
CreateSchemaRequest = _reflection.GeneratedProtocolMessageType('CreateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreateSchemaRequest)
  })
_sym_db.RegisterMessage(CreateSchemaRequest)

UpdateSchemaRequest = _reflection.GeneratedProtocolMessageType('UpdateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdateSchemaRequest)
  })
_sym_db.RegisterMessage(UpdateSchemaRequest)

SchemaRequest = _reflection.GeneratedProtocolMessageType('SchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaRequest)
  })
_sym_db.RegisterMessage(SchemaRequest)

GetRepositorySchemaRequest = _reflection.GeneratedProtocolMessageType('GetRepositorySchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYSCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositorySchemaRequest)
  })
_sym_db.RegisterMessage(GetRepositorySchemaRequest)

SchemaQuery = _reflection.GeneratedProtocolMessageType('SchemaQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAQUERY,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaQuery)
  })
_sym_db.RegisterMessage(SchemaQuery)

SchemaInfo = _reflection.GeneratedProtocolMessageType('SchemaInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAINFO,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaInfo)
  })
_sym_db.RegisterMessage(SchemaInfo)

SchemasInfo = _reflection.GeneratedProtocolMessageType('SchemasInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMASINFO,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemasInfo)
  })
_sym_db.RegisterMessage(SchemasInfo)

SchemaStatQuery = _reflection.GeneratedProtocolMessageType('SchemaStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMASTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaStatQuery)
  })
_sym_db.RegisterMessage(SchemaStatQuery)

_SCHEMA = DESCRIPTOR.services_by_name['Schema']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCHEMA.methods_by_name['create']._options = None
  _SCHEMA.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/repository/v1/schemas'
  _SCHEMA.methods_by_name['update']._options = None
  _SCHEMA.methods_by_name['update']._serialized_options = b'\202\323\344\223\002 \032\036/repository/v1/schema/{schema}'
  _SCHEMA.methods_by_name['delete']._options = None
  _SCHEMA.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002 *\036/repository/v1/schema/{schema}'
  _SCHEMA.methods_by_name['get']._options = None
  _SCHEMA.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/repository/v1/schemas/{schema}'
  _SCHEMA.methods_by_name['list']._options = None
  _SCHEMA.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/repository/v1/schemasZ\037\"\035/repository/v1/schemas/search'
  _SCHEMA.methods_by_name['stat']._options = None
  _SCHEMA.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/repository/v1/schemas/stat'
  _CREATESCHEMAREQUEST._serialized_start=240
  _CREATESCHEMAREQUEST._serialized_end=479
  _UPDATESCHEMAREQUEST._serialized_start=482
  _UPDATESCHEMAREQUEST._serialized_end=660
  _SCHEMAREQUEST._serialized_start=662
  _SCHEMAREQUEST._serialized_end=729
  _GETREPOSITORYSCHEMAREQUEST._serialized_start=731
  _GETREPOSITORYSCHEMAREQUEST._serialized_end=848
  _SCHEMAQUERY._serialized_start=851
  _SCHEMAQUERY._serialized_end=1133
  _SCHEMAQUERY_STATE._serialized_start=1089
  _SCHEMAQUERY_STATE._serialized_end=1133
  _SCHEMAINFO._serialized_start=1136
  _SCHEMAINFO._serialized_end=1475
  _SCHEMASINFO._serialized_start=1477
  _SCHEMASINFO._serialized_end=1568
  _SCHEMASTATQUERY._serialized_start=1570
  _SCHEMASTATQUERY._serialized_end=1683
  _SCHEMA._serialized_start=1686
  _SCHEMA._serialized_end=2499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_summary.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/inventory/v1/resource_summary.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"?\n\x16ResourceSummaryRequest\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"P\n\x19GetResourceSummaryRequest\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xff\x01\n\x14ResourceSummaryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nsummary_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x14\n\x0c\x63reated_date\x18\x08 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\t\"\xdb\x02\n\x13ResourceSummaryInfo\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x01\x12\r\n\x05\x63ount\x18\n \x01(\x01\x12\x14\n\x0c\x63reated_date\x18\x0b \x01(\t\x12%\n\x04\x64\x61ta\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12\x0e\n\x06region\x18\x10 \x01(\t\"m\n\x15ResourceSummariesInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.ResourceSummaryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18ResourceSummaryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf9\x03\n\x0fResourceSummary\x12\x9e\x01\n\x03get\x12\x34.spaceone.api.inventory.v1.GetResourceSummaryRequest\x1a..spaceone.api.inventory.v1.ResourceSummaryInfo\"1\x82\xd3\xe4\x93\x02+\x12)/inventory/v1/resource-group/{summary_id}\x12\xbe\x01\n\x04list\x12/.spaceone.api.inventory.v1.ResourceSummaryQuery\x1a\x30.spaceone.api.inventory.v1.ResourceSummariesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /inventory/v1/resource-summariesZ)\"\'/inventory/v1/resource-summaries/search\x12\x83\x01\n\x04stat\x12\x33.spaceone.api.inventory.v1.ResourceSummaryStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-summaries/statb\x06proto3')



_RESOURCESUMMARYREQUEST = DESCRIPTOR.message_types_by_name['ResourceSummaryRequest']
_GETRESOURCESUMMARYREQUEST = DESCRIPTOR.message_types_by_name['GetResourceSummaryRequest']
_RESOURCESUMMARYQUERY = DESCRIPTOR.message_types_by_name['ResourceSummaryQuery']
_RESOURCESUMMARYINFO = DESCRIPTOR.message_types_by_name['ResourceSummaryInfo']
_RESOURCESUMMARIESINFO = DESCRIPTOR.message_types_by_name['ResourceSummariesInfo']
_RESOURCESUMMARYSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceSummaryStatQuery']
ResourceSummaryRequest = _reflection.GeneratedProtocolMessageType('ResourceSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryRequest)
  })
_sym_db.RegisterMessage(ResourceSummaryRequest)

GetResourceSummaryRequest = _reflection.GeneratedProtocolMessageType('GetResourceSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCESUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetResourceSummaryRequest)
  })
_sym_db.RegisterMessage(GetResourceSummaryRequest)

ResourceSummaryQuery = _reflection.GeneratedProtocolMessageType('ResourceSummaryQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryQuery)
  })
_sym_db.RegisterMessage(ResourceSummaryQuery)

ResourceSummaryInfo = _reflection.GeneratedProtocolMessageType('ResourceSummaryInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryInfo)
  })
_sym_db.RegisterMessage(ResourceSummaryInfo)

ResourceSummariesInfo = _reflection.GeneratedProtocolMessageType('ResourceSummariesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARIESINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummariesInfo)
  })
_sym_db.RegisterMessage(ResourceSummariesInfo)

ResourceSummaryStatQuery = _reflection.GeneratedProtocolMessageType('ResourceSummaryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryStatQuery)
  })
_sym_db.RegisterMessage(ResourceSummaryStatQuery)

_RESOURCESUMMARY = DESCRIPTOR.services_by_name['ResourceSummary']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCESUMMARY.methods_by_name['get']._options = None
  _RESOURCESUMMARY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002+\022)/inventory/v1/resource-group/{summary_id}'
  _RESOURCESUMMARY.methods_by_name['list']._options = None
  _RESOURCESUMMARY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /inventory/v1/resource-summariesZ)\"\'/inventory/v1/resource-summaries/search'
  _RESOURCESUMMARY.methods_by_name['stat']._options = None
  _RESOURCESUMMARY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-summaries/stat'
  _RESOURCESUMMARYREQUEST._serialized_start=202
  _RESOURCESUMMARYREQUEST._serialized_end=265
  _GETRESOURCESUMMARYREQUEST._serialized_start=267
  _GETRESOURCESUMMARYREQUEST._serialized_end=347
  _RESOURCESUMMARYQUERY._serialized_start=350
  _RESOURCESUMMARYQUERY._serialized_end=605
  _RESOURCESUMMARYINFO._serialized_start=608
  _RESOURCESUMMARYINFO._serialized_end=955
  _RESOURCESUMMARIESINFO._serialized_start=957
  _RESOURCESUMMARIESINFO._serialized_end=1066
  _RESOURCESUMMARYSTATQUERY._serialized_start=1068
  _RESOURCESUMMARYSTATQUERY._serialized_end=1167
  _RESOURCESUMMARY._serialized_start=1170
  _RESOURCESUMMARY._serialized_end=1675
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/plugin/v1/supervisor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/plugin/v1/supervisor.proto\x12\x16spaceone.api.plugin.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xfd\x01\n\x18PublishSupervisorRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x12\n\nsecret_key\x18\x03 \x01(\t\x12\x37\n\x0bplugin_info\x18\x04 \x03(\x0b\x32\".spaceone.api.plugin.v1.PluginInfo\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tis_public\x18\x06 \x01(\x08\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12\'\n\x06labels\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xc8\x01\n\x19RegisterSupervisorRequest\x12\x15\n\rsupervisor_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tis_public\x18\x03 \x01(\x08\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12\'\n\x06labels\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"=\n\x11SupervisorRequest\x12\x15\n\rsupervisor_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"N\n\x14GetSupervisorRequest\x12\x15\n\rsupervisor_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"d\n\x14RecoverPluginRequest\x12\x15\n\rsupervisor_id\x18\x01 \x01(\t\x12\x11\n\tplugin_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xef\x02\n\x0eSupervisorInfo\x12\x15\n\rsupervisor_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08hostname\x18\x03 \x01(\t\x12;\n\x05state\x18\x04 \x01(\x0e\x32,.spaceone.api.plugin.v1.SupervisorInfo.State\x12\x11\n\tis_public\x18\x05 \x01(\x08\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06labels\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\"K\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0b\n\x07PENDING\x10\x03\x12\x10\n\x0c\x44ISCONNECTED\x10\x04\"\x88\x01\n\x0fSupervisorQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x15\n\rsupervisor_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tis_public\x18\x04 \x01(\x08\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"_\n\x0fSupervisorsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.plugin.v1.SupervisorInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13SupervisorStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xb6\x02\n\x0bPluginQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x15\n\rsupervisor_id\x18\x02 \x01(\t\x12\x10\n\x08hostname\x18\x03 \x01(\t\x12\x11\n\tplugin_id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x38\n\x05state\x18\x06 \x01(\x0e\x32).spaceone.api.plugin.v1.PluginQuery.State\x12\x10\n\x08\x65ndpoint\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x08 \x01(\t\"O\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x13\n\x0fRE_PROVISIONING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"\xb3\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x37\n\x05state\x18\x03 \x01(\x0e\x32(.spaceone.api.plugin.v1.PluginInfo.State\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x15\n\rsupervisor_id\x18\x05 \x01(\t\x12\x17\n\x0fsupervisor_name\x18\x06 \x01(\t\x12\x0f\n\x07managed\x18\x07 \x01(\x08\x12\x11\n\tendpoints\x18\x08 \x03(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\"O\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x13\n\x0fRE_PROVISIONING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"W\n\x0bPluginsInfo\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".spaceone.api.plugin.v1.PluginInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x90\r\n\nSupervisor\x12\x83\x01\n\x07publish\x12\x30.spaceone.api.plugin.v1.PublishSupervisorRequest\x1a&.spaceone.api.plugin.v1.SupervisorInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/plugin/v1/supervisors\x12\x9d\x01\n\x08register\x12\x31.spaceone.api.plugin.v1.RegisterSupervisorRequest\x1a&.spaceone.api.plugin.v1.SupervisorInfo\"6\x82\xd3\xe4\x93\x02\x30\"./plugin/v1/supervisor/{supervisor_id}/register\x12\x92\x01\n\x06update\x12\x31.spaceone.api.plugin.v1.RegisterSupervisorRequest\x1a&.spaceone.api.plugin.v1.SupervisorInfo\"-\x82\xd3\xe4\x93\x02\'\x1a%/plugin/v1/supervisor/{supervisor_id}\x12\x87\x01\n\nderegister\x12).spaceone.api.plugin.v1.SupervisorRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30*./plugin/v1/supervisor/{supervisor_id}/register\x12\x91\x01\n\x06\x65nable\x12).spaceone.api.plugin.v1.SupervisorRequest\x1a&.spaceone.api.plugin.v1.SupervisorInfo\"4\x82\xd3\xe4\x93\x02.\x1a,/plugin/v1/supervisor/{supervisor_id}/enable\x12\x93\x01\n\x07\x64isable\x12).spaceone.api.plugin.v1.SupervisorRequest\x1a&.spaceone.api.plugin.v1.SupervisorInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/plugin/v1/supervisor/{supervisor_id}/disable\x12\xac\x01\n\x0erecover_plugin\x12,.spaceone.api.plugin.v1.RecoverPluginRequest\x1a\".spaceone.api.plugin.v1.PluginInfo\"H\x82\xd3\xe4\x93\x02\x42\"@/plugin/v1/supervisor/{supervisor_id}/plugin/{plugin_id}/recover\x12\x8a\x01\n\x03get\x12,.spaceone.api.plugin.v1.GetSupervisorRequest\x1a&.spaceone.api.plugin.v1.SupervisorInfo\"-\x82\xd3\xe4\x93\x02\'\x12%/plugin/v1/supervisor/{supervisor_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.plugin.v1.SupervisorQuery\x1a\'.spaceone.api.plugin.v1.SupervisorsInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/plugin/v1/supervisorsZ\x1f\"\x1d/plugin/v1/supervisors/search\x12q\n\x04stat\x12+.spaceone.api.plugin.v1.SupervisorStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/plugin/v1/supervisors/stat\x12\xc7\x01\n\x0clist_plugins\x12#.spaceone.api.plugin.v1.PluginQuery\x1a#.spaceone.api.plugin.v1.PluginsInfo\"m\x82\xd3\xe4\x93\x02g\x12-/plugin/v1/supervisor/{supervisor_id}/pluginsZ6\"4/plugin/v1/supervisor/{supervisor_id}/plugins/searchb\x06proto3')



_PUBLISHSUPERVISORREQUEST = DESCRIPTOR.message_types_by_name['PublishSupervisorRequest']
_REGISTERSUPERVISORREQUEST = DESCRIPTOR.message_types_by_name['RegisterSupervisorRequest']
_SUPERVISORREQUEST = DESCRIPTOR.message_types_by_name['SupervisorRequest']
_GETSUPERVISORREQUEST = DESCRIPTOR.message_types_by_name['GetSupervisorRequest']
_RECOVERPLUGINREQUEST = DESCRIPTOR.message_types_by_name['RecoverPluginRequest']
_SUPERVISORINFO = DESCRIPTOR.message_types_by_name['SupervisorInfo']
_SUPERVISORQUERY = DESCRIPTOR.message_types_by_name['SupervisorQuery']
_SUPERVISORSINFO = DESCRIPTOR.message_types_by_name['SupervisorsInfo']
_SUPERVISORSTATQUERY = DESCRIPTOR.message_types_by_name['SupervisorStatQuery']
_PLUGINQUERY = DESCRIPTOR.message_types_by_name['PluginQuery']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_PLUGINSINFO = DESCRIPTOR.message_types_by_name['PluginsInfo']
_SUPERVISORINFO_STATE = _SUPERVISORINFO.enum_types_by_name['State']
_PLUGINQUERY_STATE = _PLUGINQUERY.enum_types_by_name['State']
_PLUGININFO_STATE = _PLUGININFO.enum_types_by_name['State']
PublishSupervisorRequest = _reflection.GeneratedProtocolMessageType('PublishSupervisorRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHSUPERVISORREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PublishSupervisorRequest)
  })
_sym_db.RegisterMessage(PublishSupervisorRequest)

RegisterSupervisorRequest = _reflection.GeneratedProtocolMessageType('RegisterSupervisorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERSUPERVISORREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.RegisterSupervisorRequest)
  })
_sym_db.RegisterMessage(RegisterSupervisorRequest)

SupervisorRequest = _reflection.GeneratedProtocolMessageType('SupervisorRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUPERVISORREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.SupervisorRequest)
  })
_sym_db.RegisterMessage(SupervisorRequest)

GetSupervisorRequest = _reflection.GeneratedProtocolMessageType('GetSupervisorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUPERVISORREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.GetSupervisorRequest)
  })
_sym_db.RegisterMessage(GetSupervisorRequest)

RecoverPluginRequest = _reflection.GeneratedProtocolMessageType('RecoverPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECOVERPLUGINREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.RecoverPluginRequest)
  })
_sym_db.RegisterMessage(RecoverPluginRequest)

SupervisorInfo = _reflection.GeneratedProtocolMessageType('SupervisorInfo', (_message.Message,), {
  'DESCRIPTOR' : _SUPERVISORINFO,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.SupervisorInfo)
  })
_sym_db.RegisterMessage(SupervisorInfo)

SupervisorQuery = _reflection.GeneratedProtocolMessageType('SupervisorQuery', (_message.Message,), {
  'DESCRIPTOR' : _SUPERVISORQUERY,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.SupervisorQuery)
  })
_sym_db.RegisterMessage(SupervisorQuery)

SupervisorsInfo = _reflection.GeneratedProtocolMessageType('SupervisorsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SUPERVISORSINFO,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.SupervisorsInfo)
  })
_sym_db.RegisterMessage(SupervisorsInfo)

SupervisorStatQuery = _reflection.GeneratedProtocolMessageType('SupervisorStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SUPERVISORSTATQUERY,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.SupervisorStatQuery)
  })
_sym_db.RegisterMessage(SupervisorStatQuery)

PluginQuery = _reflection.GeneratedProtocolMessageType('PluginQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINQUERY,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PluginQuery)
  })
_sym_db.RegisterMessage(PluginQuery)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

PluginsInfo = _reflection.GeneratedProtocolMessageType('PluginsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINSINFO,
  '__module__' : 'spaceone.api.plugin.v1.supervisor_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PluginsInfo)
  })
_sym_db.RegisterMessage(PluginsInfo)

_SUPERVISOR = DESCRIPTOR.services_by_name['Supervisor']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUPERVISOR.methods_by_name['publish']._options = None
  _SUPERVISOR.methods_by_name['publish']._serialized_options = b'\202\323\344\223\002\030\"\026/plugin/v1/supervisors'
  _SUPERVISOR.methods_by_name['register']._options = None
  _SUPERVISOR.methods_by_name['register']._serialized_options = b'\202\323\344\223\0020\"./plugin/v1/supervisor/{supervisor_id}/register'
  _SUPERVISOR.methods_by_name['update']._options = None
  _SUPERVISOR.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\'\032%/plugin/v1/supervisor/{supervisor_id}'
  _SUPERVISOR.methods_by_name['deregister']._options = None
  _SUPERVISOR.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\0020*./plugin/v1/supervisor/{supervisor_id}/register'
  _SUPERVISOR.methods_by_name['enable']._options = None
  _SUPERVISOR.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002.\032,/plugin/v1/supervisor/{supervisor_id}/enable'
  _SUPERVISOR.methods_by_name['disable']._options = None
  _SUPERVISOR.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002/\032-/plugin/v1/supervisor/{supervisor_id}/disable'
  _SUPERVISOR.methods_by_name['recover_plugin']._options = None
  _SUPERVISOR.methods_by_name['recover_plugin']._serialized_options = b'\202\323\344\223\002B\"@/plugin/v1/supervisor/{supervisor_id}/plugin/{plugin_id}/recover'
  _SUPERVISOR.methods_by_name['get']._options = None
  _SUPERVISOR.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\'\022%/plugin/v1/supervisor/{supervisor_id}'
  _SUPERVISOR.methods_by_name['list']._options = None
  _SUPERVISOR.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/plugin/v1/supervisorsZ\037\"\035/plugin/v1/supervisors/search'
  _SUPERVISOR.methods_by_name['stat']._options = None
  _SUPERVISOR.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/plugin/v1/supervisors/stat'
  _SUPERVISOR.methods_by_name['list_plugins']._options = None
  _SUPERVISOR.methods_by_name['list_plugins']._serialized_options = b'\202\323\344\223\002g\022-/plugin/v1/supervisor/{supervisor_id}/pluginsZ6\"4/plugin/v1/supervisor/{supervisor_id}/plugins/search'
  _PUBLISHSUPERVISORREQUEST._serialized_start=191
  _PUBLISHSUPERVISORREQUEST._serialized_end=444
  _REGISTERSUPERVISORREQUEST._serialized_start=447
  _REGISTERSUPERVISORREQUEST._serialized_end=647
  _SUPERVISORREQUEST._serialized_start=649
  _SUPERVISORREQUEST._serialized_end=710
  _GETSUPERVISORREQUEST._serialized_start=712
  _GETSUPERVISORREQUEST._serialized_end=790
  _RECOVERPLUGINREQUEST._serialized_start=792
  _RECOVERPLUGINREQUEST._serialized_end=892
  _SUPERVISORINFO._serialized_start=895
  _SUPERVISORINFO._serialized_end=1262
  _SUPERVISORINFO_STATE._serialized_start=1187
  _SUPERVISORINFO_STATE._serialized_end=1262
  _SUPERVISORQUERY._serialized_start=1265
  _SUPERVISORQUERY._serialized_end=1401
  _SUPERVISORSINFO._serialized_start=1403
  _SUPERVISORSINFO._serialized_end=1498
  _SUPERVISORSTATQUERY._serialized_start=1500
  _SUPERVISORSTATQUERY._serialized_end=1594
  _PLUGINQUERY._serialized_start=1597
  _PLUGINQUERY._serialized_end=1907
  _PLUGINQUERY_STATE._serialized_start=1828
  _PLUGINQUERY_STATE._serialized_end=1907
  _PLUGININFO._serialized_start=1910
  _PLUGININFO._serialized_end=2217
  _PLUGININFO_STATE._serialized_start=1828
  _PLUGININFO_STATE._serialized_end=1907
  _PLUGINSINFO._serialized_start=2219
  _PLUGINSINFO._serialized_end=2306
  _SUPERVISOR._serialized_start=2309
  _SUPERVISOR._serialized_end=3989
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/notification_usage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/notification/v1/notification_usage.proto\x12\x1cspaceone.api.notification.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"l\n\x16NotificationUsageQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bprotocol_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x8b\x01\n\x15NotificationUsageInfo\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x12\n\nusage_date\x18\x02 \x01(\t\x12\x13\n\x0busage_month\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\x05\x12\x12\n\nfail_count\x18\x05 \x01(\x05\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"s\n\x16NotificationUsagesInfo\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32\x33.spaceone.api.notification.v1.NotificationUsageInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"e\n\x1aNotificationUsageStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf4\x02\n\x11NotificationUsage\x12\xcf\x01\n\x04list\x12\x34.spaceone.api.notification.v1.NotificationUsageQuery\x1a\x34.spaceone.api.notification.v1.NotificationUsagesInfo\"[\x82\xd3\xe4\x93\x02U\x12$/notification/v1/notification-usagesZ-\"+/notification/v1/notification-usages/search\x12\x8c\x01\n\x04stat\x12\x38.spaceone.api.notification.v1.NotificationUsageStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/notification/v1/notification-usages/statb\x06proto3')



_NOTIFICATIONUSAGEQUERY = DESCRIPTOR.message_types_by_name['NotificationUsageQuery']
_NOTIFICATIONUSAGEINFO = DESCRIPTOR.message_types_by_name['NotificationUsageInfo']
_NOTIFICATIONUSAGESINFO = DESCRIPTOR.message_types_by_name['NotificationUsagesInfo']
_NOTIFICATIONUSAGESTATQUERY = DESCRIPTOR.message_types_by_name['NotificationUsageStatQuery']
NotificationUsageQuery = _reflection.GeneratedProtocolMessageType('NotificationUsageQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONUSAGEQUERY,
  '__module__' : 'spaceone.api.notification.v1.notification_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationUsageQuery)
  })
_sym_db.RegisterMessage(NotificationUsageQuery)

NotificationUsageInfo = _reflection.GeneratedProtocolMessageType('NotificationUsageInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONUSAGEINFO,
  '__module__' : 'spaceone.api.notification.v1.notification_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationUsageInfo)
  })
_sym_db.RegisterMessage(NotificationUsageInfo)

NotificationUsagesInfo = _reflection.GeneratedProtocolMessageType('NotificationUsagesInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONUSAGESINFO,
  '__module__' : 'spaceone.api.notification.v1.notification_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationUsagesInfo)
  })
_sym_db.RegisterMessage(NotificationUsagesInfo)

NotificationUsageStatQuery = _reflection.GeneratedProtocolMessageType('NotificationUsageStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONUSAGESTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.notification_usage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationUsageStatQuery)
  })
_sym_db.RegisterMessage(NotificationUsageStatQuery)

_NOTIFICATIONUSAGE = DESCRIPTOR.services_by_name['NotificationUsage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFICATIONUSAGE.methods_by_name['list']._options = None
  _NOTIFICATIONUSAGE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002U\022$/notification/v1/notification-usagesZ-\"+/notification/v1/notification-usages/search'
  _NOTIFICATIONUSAGE.methods_by_name['stat']._options = None
  _NOTIFICATIONUSAGE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/notification/v1/notification-usages/stat'
  _NOTIFICATIONUSAGEQUERY._serialized_start=181
  _NOTIFICATIONUSAGEQUERY._serialized_end=289
  _NOTIFICATIONUSAGEINFO._serialized_start=292
  _NOTIFICATIONUSAGEINFO._serialized_end=431
  _NOTIFICATIONUSAGESINFO._serialized_start=433
  _NOTIFICATIONUSAGESINFO._serialized_end=548
  _NOTIFICATIONUSAGESTATQUERY._serialized_start=550
  _NOTIFICATIONUSAGESTATQUERY._serialized_end=651
  _NOTIFICATIONUSAGE._serialized_start=654
  _NOTIFICATIONUSAGE._serialized_end=1026
# @@protoc_insertion_point(module_scope)
